package Rinci;

our $VERSION = '1.1.49'; # VERSION

1;
# ABSTRACT: Language-neutral metadata for your code

__END__

=pod

=encoding UTF-8

=head1 NAME

Rinci - Language-neutral metadata for your code

=head1 VERSION

This document describes version 1.1.49 of Rinci (from Perl distribution Rinci), released on 2014-06-13.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Rinci>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Rinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
